@@ -1,10 +1,13 @@
 from __future__ import with_statement
 from difflib import SequenceMatcher
+import os
 from unittest import TestCase
+import sys
 
 from django import template
 from django.conf import settings
 from django.template.loader import render_to_string
+import pep8
 
 from sekizai.context import SekizaiContext
 from sekizai.helpers import get_namespaces
@@ -19,6 +22,11 @@ try:
 except NameError:
     unicode_compat = str
 
+try:
+    from io import StringIO
+except ImportError:
+    from StringIO import StringIO
+
 
 def null_processor(context, data, namespace):
     return ''
@@ -32,23 +40,24 @@ class SettingsOverride(object):
     """
     Overrides Django settings within a context and resets them to their inital
     values on exit.
-    
+
     Example:
-    
+
         with SettingsOverride(DEBUG=True):
             # do something
     """
-    class NULL: pass
-    
+    class NULL:
+        pass
+
     def __init__(self, **overrides):
         self.overrides = overrides
-        
+
     def __enter__(self):
         self.old = {}
         for key, value in self.overrides.items():
             self.old[key] = getattr(settings, key, self.NULL)
             setattr(settings, key, value)
-        
+
     def __exit__(self, type, value, traceback):
         for key, value in self.old.items():
             if value is self.NULL:
@@ -57,38 +66,58 @@ class SettingsOverride(object):
                 setattr(settings, key, value)
 
 
-class Match(tuple): # pragma: no cover
+class CaptureStdout(object):
+    """
+    Overrides sys.stdout with a StringIO stream.
+    """
+    def __init__(self):
+        self.old = None
+
+    def __enter__(self):
+        self.old = sys.stdout
+        new = sys.stdout = StringIO()
+        return new
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        sys.stdout = self.old
+
+
+class Match(tuple):  # pragma: no cover
     @property
     def a(self):
         return self[0]
-    
+
     @property
     def b(self):
         return self[1]
-    
+
     @property
     def size(self):
         return self[2]
 
 
-def _backwards_compat_match(thing): # pragma: no cover
+def _backwards_compat_match(thing):  # pragma: no cover
     if isinstance(thing, tuple):
         return Match(thing)
     return thing
 
+
 class BitDiffResult(object):
+
     def __init__(self, status, message):
         self.status = status
         self.message = message
 
 
 class BitDiff(object):
+
     """
     Visual aid for failing tests
     """
+
     def __init__(self, expected):
         self.expected = [repr(unicode_compat(bit)) for bit in expected]
-        
+
     def test(self, result):
         result = [repr(unicode_compat(bit)) for bit in result]
         if self.expected == result:
@@ -138,7 +167,7 @@ class SekizaiTestCase(TestCase):
     def _render(self, tpl, ctx=None, ctxclass=SekizaiContext):
         ctx = ctx or {}
         return render_to_string(tpl, ctxclass(ctx))
-    
+
     def _get_bits(self, tpl, ctx=None, ctxclass=SekizaiContext):
         ctx = ctx or {}
         rendered = self._render(tpl, ctx, ctxclass)
@@ -147,7 +176,7 @@ class SekizaiTestCase(TestCase):
                             for bit in rendered.split('\n')] if bit
         ]
         return bits, rendered
-        
+
     def _test(self, tpl, res, ctx=None, ctxclass=SekizaiContext):
         """
         Helper method to render template and compare it's bits
@@ -158,7 +187,18 @@ class SekizaiTestCase(TestCase):
         result = differ.test(bits)
         self.assertTrue(result.status, result.message)
         return rendered
-        
+
+    def test_pep8(self):
+        sekizai_dir = os.path.dirname(os.path.abspath(__file__))
+        pep8style = pep8.StyleGuide()
+        with CaptureStdout() as stdout:
+            result = pep8style.check_files([sekizai_dir])
+            errors = stdout.getvalue()
+        self.assertEqual(
+            result.total_errors, 0,
+            "Code not PEP8 compliant:\n{0}".format(errors)
+        )
+
     def test_basic_dual_block(self):
         """
         Basic dual block testing
@@ -182,17 +222,17 @@ class SekizaiTestCase(TestCase):
         """
         bits = ["mycontent"]
         self._test("eat.html", bits)
-        
+
     def test_sekizai_context_required(self):
         """
-        Test that the template tags properly fail if not used with either 
+        Test that the template tags properly fail if not used with either
         SekizaiContext or the context processor.
         """
         self.assertRaises(
             template.TemplateSyntaxError,
             self._render, 'basic.html', {}, template.Context
         )
-        
+
     def test_complex_template_inheritance(self):
         """
         Test that (complex) template inheritances work properly
@@ -232,14 +272,14 @@ class SekizaiTestCase(TestCase):
             "body end"
         ]
         self._test("inherit/super_blocks.html", bits)
-        
+
     def test_namespace_isolation(self):
         """
         Tests that namespace isolation works
         """
         bits = ["the same file", "the same file"]
         self._test('namespaces.html', bits)
-        
+
     def test_variable_namespaces(self):
         """
         Tests variables and filtered variables as block names.
@@ -256,41 +296,41 @@ class SekizaiTestCase(TestCase):
             template.TemplateSyntaxError,
             self._render, 'errors/failadd.html'
         )
-    
+
     def test_invalid_renderblock(self):
         self.assertRaises(
             template.TemplateSyntaxError,
             self._render, 'errors/failrender.html'
         )
-    
+
     def test_invalid_include(self):
         self.assertRaises(
             template.TemplateSyntaxError,
             self._render, 'errors/failinc.html'
         )
-        
+
     def test_invalid_basetemplate(self):
         self.assertRaises(
             template.TemplateSyntaxError,
             self._render, 'errors/failbase.html'
         )
-        
+
     def test_invalid_basetemplate_two(self):
         self.assertRaises(
             template.TemplateSyntaxError,
             self._render, 'errors/failbase2.html'
         )
-        
+
     def test_with_data(self):
         """
         Tests the with_data/add_data tags.
         """
         bits = ["1", "2"]
         self._test('with_data.html', bits)
-        
+
     def test_easy_inheritance(self):
         self.assertEqual('content', self._render("easy_inherit.html").strip())
-        
+
     def test_validate_context(self):
         sekizai_ctx = SekizaiContext()
         django_ctx = template.Context()
@@ -304,18 +344,18 @@ class SekizaiTestCase(TestCase):
             self.assertEqual(validate_context(sekizai_ctx), True)
             bits = ['some content', 'more content', 'final content']
             self._test('basic.html', bits, ctxclass=template.Context)
-            
+
     def test_post_processor_null(self):
         bits = ['header', 'footer']
         self._test('processors/null.html', bits)
-            
+
     def test_post_processor_namespace(self):
         bits = ['header', 'footer', 'js']
         self._test('processors/namespace.html', bits)
-        
+
     def test_import_processor_failfast(self):
         self.assertRaises(TypeError, import_processor, 'invalidpath')
-        
+
     def test_unique(self):
         bits = ['unique data']
         self._test('unique.html', bits)
@@ -340,18 +380,19 @@ class SekizaiTestCase(TestCase):
 
 
 class HelperTests(TestCase):
+
     def test_validate_template_js_css(self):
         self.assertTrue(validate_template('basic.html', ['js', 'css']))
-    
+
     def test_validate_template_js(self):
         self.assertTrue(validate_template('basic.html', ['js']))
-        
+
     def test_validate_template_css(self):
         self.assertTrue(validate_template('basic.html', ['css']))
-        
+
     def test_validate_template_empty(self):
         self.assertTrue(validate_template('basic.html', []))
-        
+
     def test_validate_template_notfound(self):
         self.assertFalse(validate_template('basic.html', ['notfound']))
 
@@ -375,7 +416,7 @@ class HelperTests(TestCase):
 
     def test_get_namespaces_null_ext(self):
         self.assertEqual(get_namespaces('inherit/nullext.html'), [])
-        
+
     def test_deactivate_validate_template(self):
         with SettingsOverride(SEKIZAI_IGNORE_VALIDATION=True):
             self.assertTrue(validate_template('basic.html', ['js', 'css']))
